ConnectionFailure class

Inheritance

Constructors

ConnectionFailure({String? message, String? dioError})

Properties

dioError ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited